@@ -13,4 +13,20 @@
 # Finally, mms may include this parameter:
 # $4 = Group Contact Name or Number (if number not in contacts)
 
-mpv --quiet --no-video /usr/share/sxmo/notify.ogg
+# shellcheck source=scripts/core/sxmo_common.sh
+. sxmo_common.sh
+
+case "$(cat "$XDG_CONFIG_HOME"/sxmo/.ringmode)" in
+	Mute)
+		;;
+	Vibrate)
+		sxmo_vibrate 500
+		;;
+	Ring)
+		mpv --no-resume-playback --quiet --no-video "$SXMO_TEXTSOUND"
+		;;
+	*) #Default: ring&vibrate
+		mpv --no-resume-playback --quiet --no-video "$SXMO_TEXTSOUND" &
+		sxmo_vibrate 500
+		;;
+esac
