@@ -47,3 +47,37 @@ sxmo_log() {
 sxmo_debug() {
 	printf "%s %s DEBUG: %s\n" "$(date +%H:%M:%S)" "${0##*/}" "$*" >&2
 }
+
+# Outputs the paths of the specified file/dir path in XDG_DATA_DIRS.
+# Will output $2 instances (default 1, 0 for no limit)
+# Will separate instances with $3 (default " ")
+#
+# xdg_data_path icons/open.ico
+# -> "/usr/local/share/icons/open.ico"
+#
+# xdg_data_path sxmo/appcfg
+# -> "/usr/share/sxmo/appcfg"
+#
+# xdg_data_path icons 0 "|"
+# -> "/usr/local/share/icons|/usr/share/icons"
+xdg_data_path() {
+	filepath=$1
+	instance_count=${2:-1}
+	sep=${3:-" "}
+
+	IFS=':'
+	instance=0
+	for dir in $XDG_DATA_DIRS
+	do
+		if [ -e "$dir/$filepath" ]; then
+			if [ "$instance" -ge "$instance_count" ] && [ "$instance_count" != "0" ]; then
+				break
+			fi
+			if [ $instance -gt 0 ]; then
+				printf '%s' "${sep}"
+			fi
+			printf '%s' "${dir}/${filepath}"
+			instance=$((instance+1))
+		fi
+	done
+}
