@@ -4,43 +4,21 @@
 . sxmo_common.sh
 
 setup_audio() {
-	unmute_mic
+	# implies speaker off, mic not muted
 	enable_call_audio_mode
-	disable_speaker
-
-	i=0
-	while (! is_unmuted_mic) || (! is_call_audio_mode) || (! is_disabled_speaker); do
-		i=$((i+1))
-		if [ "$i" -gt 5 ]; then
-			return 1
-		fi
-
-		sleep 0.2
-
-		unmute_mic
-		enable_call_audio_mode
-		disable_speaker
-	done
 }
 
 reset_audio() {
-	mute_mic
+	# implies speaker on, mic muted
 	disable_call_audio_mode
-	enable_speaker
+}
 
-	i=0
-	while (! is_muted_mic) || (! is_default_audio_mode) || (! is_enabled_speaker); do
-		i=$((i+1))
-		if [ "$i" -gt 5 ]; then
-			return 1
-		fi
-
-		sleep 0.2
-
-		mute_mic
-		disable_call_audio_mode
+toggle_speaker() {
+	if is_enabled_speaker; then
+		disable_speaker
+	else
 		enable_speaker
-	done
+	fi
 }
 
 is_muted_mic() {
@@ -52,11 +30,11 @@ is_unmuted_mic() {
 }
 
 mute_mic() {
-	callaudiocli -u 1
+	callaudiocli -u 1 || sxmo_log "ERR: callaudiocli -u 1 failed"
 }
 
 unmute_mic() {
-	callaudiocli -u 0
+	callaudiocli -u 0 || sxmo_log "ERR: callaudiocli -u 0 failed"
 }
 
 is_call_audio_mode() {
@@ -68,11 +46,11 @@ is_default_audio_mode() {
 }
 
 enable_call_audio_mode() {
-	callaudiocli -m 1
+	callaudiocli -m 1 || sxmo_log "ERR: callaudiocl -m 1 failed"
 }
 
 disable_call_audio_mode() {
-	callaudiocli -m 0
+	callaudiocli -m 0 || sxmo_log "ERR: callaudiocli -m 0 failed"
 }
 
 is_enabled_speaker() {
@@ -84,11 +62,11 @@ is_disabled_speaker() {
 }
 
 enable_speaker() {
-	callaudiocli -s 1
+	callaudiocli -s 1 || sxmo_log "ERR: callaudiocli -s 1 failed"
 }
 
 disable_speaker() {
-	callaudiocli -s 0
+	callaudiocli -s 0 || sxmo_log "ERR: callaudiocli -s 0 failed"
 }
 
 "$@"
